#!/usr/bin/env bash
# 
# SCRIPT NAME:
# prerequisites.sh
#
# AUTHOR:
# Severin Kaderli <severin@kaderli.dev>
#
# DESCRIPTION:
# Installs the prerequisites for the installation script.
output::section "Prerequisites"

output::log "Installing requirements for install script"
sudo pacman -S sudo ccache git base-devel --noconfirm --needed |& output::debug
output::success "Requirements successfully installed"

is_paru_installed=$(command -v paru)
output::log "Installing paru"
if [ -z "${is_paru_installed}" ]; then
    TMP_DIR=$(mktemp -d)
    git clone https://aur.archlinux.org/paru.git "${TMP_DIR}" |& output::debug

    (
        cd "${TMP_DIR}"|| exit
        makepkg -si --noconfirm --skippgpcheck |& output::debug
    )

    output::success "paru installed"
else
    output::success "paru is already installed"
fi